==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/EndpointPropertiesCustomHeadersArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.EndpointPropertiesCustomHeadersArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Custom header name and value.
 * @property name Header name.
 * @property value Header value.
 */
public data class EndpointPropertiesCustomHeadersArgs(
    public val name: Output<String>? = null,
    public val `value`: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.EndpointPropertiesCustomHeadersArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.EndpointPropertiesCustomHeadersArgs =
        com.pulumi.azurenative.network.inputs.EndpointPropertiesCustomHeadersArgs.builder()
            .name(name?.applyValue({ args0 -> args0 }))
            .`value`(`value`?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [EndpointPropertiesCustomHeadersArgs].
 */
@PulumiTagMarker
public class EndpointPropertiesCustomHeadersArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value Header name.
     */
    @JvmName("qsmmywgbtdstdkfs")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Header value.
     */
    @JvmName("nuohdrjqgrkrfnim")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value Header name.
     */
    @JvmName("hdfhiienvcxcattu")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Header value.
     */
    @JvmName("iscxhexclsbjptxy")
    public suspend fun `value`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): EndpointPropertiesCustomHeadersArgs = EndpointPropertiesCustomHeadersArgs(
        name = name,
        `value` = `value`,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/EndpointPropertiesCustomHeadersArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.EndpointPropertiesCustomHeadersArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Custom header name and value.
 * @property name Header name.
 * @property value Header value.
 */
public data class EndpointPropertiesCustomHeadersArgs(
    public val name: Output<String>? = null,
    public val `value`: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.EndpointPropertiesCustomHeadersArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.EndpointPropertiesCustomHeadersArgs =
        com.pulumi.azurenative.network.inputs.EndpointPropertiesCustomHeadersArgs.builder()
            .name(name?.applyValue({ args0 -> args0 }))
            .`value`(`value`?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [EndpointPropertiesCustomHeadersArgs].
 */
@PulumiTagMarker
public class EndpointPropertiesCustomHeadersArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value Header name.
     */
    @JvmName("lgpniyhkvucstxge")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Header value.
     */
    @JvmName("fdlpsdiboqguqhyr")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value Header name.
     */
    @JvmName("jgldrvbkudlalemq")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    /**
     * @param value Header value.
     */
    @JvmName("ubfquipkfgkwuuml")
    public suspend fun `value`(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): EndpointPropertiesCustomHeadersArgs = EndpointPropertiesCustomHeadersArgs(
        name = name,
        `value` = `value`,
    )
}
